@@ -19,17 +19,23 @@ CHISEL_DOC_HTML = b'''\
 <!DOCTYPE html>
 <html lang="en">
     <head>
+        <title>Chisel</title>
         <meta charset="UTF-8">
         <meta name="viewport" content="width=device-width, initial-scale=1">
-        <link rel="stylesheet" href="https://craigahobbs.github.io/chisel-doc/app.css">
-        <link rel="stylesheet" href="https://craigahobbs.github.io/chisel-doc/markdown-model.css">
-        <link rel="stylesheet" href="https://craigahobbs.github.io/chisel-doc/schema-markdown-doc.css">
+        <link rel="stylesheet" href="https://craigahobbs.github.io/markdown-up/markdown-model.css">
+        <link rel="stylesheet" href="https://craigahobbs.github.io/markdown-up/app.css">
     </head>
     <body>
     </body>
     <script type="module">
-        import {ChiselDoc} from 'https://craigahobbs.github.io/chisel-doc/lib/app.js';
-        const app = new ChiselDoc(window);
+        import {MarkdownUp} from 'https://craigahobbs.github.io/markdown-up/lib/app.js';
+        const app = new MarkdownUp(window, {
+            'markdownText': `\
+~~~ markdown-script
+include 'https://craigahobbs.github.io/chisel/doc/app.mds'
+chiselDoc()
+~~~
+`});
         app.run();
     </script>
 </html>
@@ -161,7 +167,7 @@ action chisel_doc_request
 '''
 
     def __init__(self, requests=None, urls=(('GET', '/doc_request'),)):
-        super().__init__(self._doc_request, name='chisel_doc_request', urls=urls, types=dict(TYPE_MODEL['types']), spec=self.SPEC)
+        super().__init__(self._doc_request, name='chisel_doc_request', urls=urls, types=dict(TYPE_MODEL), spec=self.SPEC)
         if requests is not None:
             #: Optional list of requests to document or None. If None, the applications request collection is used.
             self.requests = {request.name: request for request in requests}
